import { Routes, Route, Outlet } from "react-router-dom";
import { Suspense, lazy } from "react";
import { ProtectedRoute, AdminRoute, ExpertRoute, PublicOnlyRoute } from "./components/auth/ProtectedRoute";
import { LanguageProvider } from "./context/LanguageContext";

// Loading component
const LoadingSpinner = () => (
  <div className="min-h-screen flex items-center justify-center">
    <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-gray-900"></div>
  </div>
);

// Lazy load all pages
const Index = lazy(() => import("./pages/Index"));
const NotFound = lazy(() => import("./pages/NotFound"));
const Unauthorized = lazy(() => import("./pages/Unauthorized"));
const UserDashboard = lazy(() => import("./pages/user/UserDashboard"));

// Public Pages
const About = lazy(() => import("./pages/public/About"));
const Restaurants = lazy(() => import("./pages/public/Restaurants"));
const RestaurantDetails = lazy(() => import("./pages/public/RestaurantDetails"));
const Experts = lazy(() => import("./pages/public/Experts"));
const ExpertProfile = lazy(() => import("./pages/public/ExpertProfile"));
const SignUp = lazy(() => import("./pages/public/SignUp"));
const Login = lazy(() => import("./pages/public/Login"));
const ForgotPassword = lazy(() => import("./pages/public/ForgotPassword"));
const Contact = lazy(() => import("./pages/public/Contact"));
const JoinAsExpert = lazy(() => import("./pages/public/JoinAsExpert"));
const PrivacyPolicy = lazy(() => import("./pages/public/PrivacyPolicy"));
const TermsOfService = lazy(() => import("./pages/public/TermsOfService"));
const DataDeletion = lazy(() => import("./pages/public/DataDeletion"));

// User Pages
const SavedRestaurants = lazy(() => import("./pages/user/SavedRestaurants"));
const FollowedExperts = lazy(() => import("./pages/user/FollowedExperts"));
const AccountSettings = lazy(() => import("./pages/user/AccountSettings"));
const UserProfile = lazy(() => import("./pages/user/UserProfile"));

// Expert Pages
const ExpertProfilePage = lazy(() => import("./pages/expert/ExpertProfile"));
const ExpertRestaurants = lazy(() => import("./pages/expert/ExpertRestaurants"));
const RestaurantSuggestionForm = lazy(() => import("./pages/expert/RestaurantSuggestionForm"));

// Admin Pages
const AdminExperts = lazy(() => import("./pages/admin/AdminExperts"));
const AdminRestaurants = lazy(() => import("./pages/admin/AdminRestaurants"));
const AdminUsers = lazy(() => import("./pages/admin/AdminUsers"));
const AdminAnalytics = lazy(() => import("./pages/admin/AdminAnalytics"));

function App() {
  return (
    <LanguageProvider>
      <Suspense fallback={<LoadingSpinner />}>
        <Routes>
          {/* Public Routes */}
          <Route path="/" element={<Index />} />
          <Route path="/restaurants" element={<Restaurants />} />
          <Route path="/restaurants/:id" element={<RestaurantDetails />} />
          <Route path="/experts" element={<Experts />} />
          <Route path="/experts/:username" element={<ExpertProfile />} />
          <Route path="/contact" element={<Contact />} />
          <Route path="/about" element={<About />} />
          <Route path="/privacy-policy" element={<PrivacyPolicy />} />
          <Route path="/terms-of-service" element={<TermsOfService />} />
          <Route path="/data-deletion" element={<DataDeletion />} />
          <Route path="/unauthorized" element={<Unauthorized />} />
          
          {/* Authentication Routes - Only accessible when not logged in */}
          <Route path="/signup" element={<PublicOnlyRoute><SignUp /></PublicOnlyRoute>} />
          <Route path="/login" element={<PublicOnlyRoute><Login /></PublicOnlyRoute>} />
          <Route path="/forgot-password" element={<PublicOnlyRoute><ForgotPassword /></PublicOnlyRoute>} />
          <Route path="/join-as-expert" element={<JoinAsExpert />} />
          
          {/* User Routes - Protected */}
          <Route path="/user/dashboard" element={<ProtectedRoute><UserDashboard /></ProtectedRoute>} />
          <Route path="/dashboard" element={<ProtectedRoute><UserDashboard /></ProtectedRoute>} />
          <Route path="/user/saved" element={<ProtectedRoute><SavedRestaurants /></ProtectedRoute>} />
          <Route path="/user/followed-experts" element={<ProtectedRoute><FollowedExperts /></ProtectedRoute>} />
          <Route path="/user/account/settings" element={<ProtectedRoute><AccountSettings /></ProtectedRoute>} />
          <Route path="/user/profile" element={<ProtectedRoute><UserProfile /></ProtectedRoute>} />
          
          {/* Expert Routes - Protected for experts */}
          <Route path="/expert/profile" element={<ExpertRoute><ExpertProfilePage /></ExpertRoute>} />
          <Route path="/expert/restaurants" element={<ExpertRoute><ExpertRestaurants /></ExpertRoute>} />
          
          {/* Admin Routes - Protected for admins */}
          <Route path="/admin/experts" element={<AdminRoute><AdminExperts /></AdminRoute>} />
          <Route path="/admin/restaurants" element={<AdminRoute><AdminRestaurants /></AdminRoute>} />
          <Route path="/admin/users" element={<AdminRoute><AdminUsers /></AdminRoute>} />
          <Route path="/admin/analytics" element={<AdminRoute><AdminAnalytics /></AdminRoute>} />
          
          {/* 404 Route */}
          <Route path="*" element={<NotFound />} />
        </Routes>
      </Suspense>
    </LanguageProvider>
  );
}

export default App;
